@@ -1,7 +1,13 @@
 import sys
 
-from lldb import SBData, SBError, eBasicTypeLong, eBasicTypeUnsignedLong, \
-    eBasicTypeUnsignedChar
+from lldb import (
+    SBData,
+    SBError,
+    SBValue,
+    eBasicTypeLong,
+    eBasicTypeUnsignedLong,
+    eBasicTypeUnsignedChar,
+)
 
 # from lldb.formatters import Logger
 
@@ -32,35 +38,43 @@ from lldb import SBData, SBError, eBasicTypeLong, eBasicTypeUnsignedLong, \
 # You can find more information and examples here:
 #   1. https://lldb.llvm.org/varformats.html
 #   2. https://lldb.llvm.org/use/python-reference.html
-#   3. https://lldb.llvm.org/python_reference/lldb.formatters.cpp.libcxx-pysrc.html
+#   3. https://github.com/llvm/llvm-project/blob/llvmorg-8.0.1/lldb/www/python_reference/lldb.formatters.cpp-pysrc.html
 #   4. https://github.com/llvm-mirror/lldb/tree/master/examples/summaries/cocoa
 ####################################################################################################
 
 PY3 = sys.version_info[0] == 3
 
 
+class LLDBOpaque:
+    """
+    An marker type for use in type hints to denote LLDB bookkeeping variables. Values marked with
+    this type should never be used except when passing as an argument to an LLDB function.
+    """
+
+
 class ValueBuilder:
-    def __init__(self, valobj):
-        # type: (SBValue) -> ValueBuilder
+    def __init__(self, valobj: SBValue):
         self.valobj = valobj
         process = valobj.GetProcess()
         self.endianness = process.GetByteOrder()
         self.pointer_size = process.GetAddressByteSize()
 
-    def from_int(self, name, value):
-        # type: (str, int) -> SBValue
+    def from_int(self, name: str, value: int) -> SBValue:
         type = self.valobj.GetType().GetBasicType(eBasicTypeLong)
-        data = SBData.CreateDataFromSInt64Array(self.endianness, self.pointer_size, [value])
+        data = SBData.CreateDataFromSInt64Array(
+            self.endianness, self.pointer_size, [value]
+        )
         return self.valobj.CreateValueFromData(name, data, type)
 
-    def from_uint(self, name, value):
-        # type: (str, int) -> SBValue
+    def from_uint(self, name: str, value: int) -> SBValue:
         type = self.valobj.GetType().GetBasicType(eBasicTypeUnsignedLong)
-        data = SBData.CreateDataFromUInt64Array(self.endianness, self.pointer_size, [value])
+        data = SBData.CreateDataFromUInt64Array(
+            self.endianness, self.pointer_size, [value]
+        )
         return self.valobj.CreateValueFromData(name, data, type)
 
 
-def unwrap_unique_or_non_null(unique_or_nonnull):
+def unwrap_unique_or_non_null(unique_or_nonnull: SBValue) -> SBValue:
     # BACKCOMPAT: rust 1.32
     # https://github.com/rust-lang/rust/commit/7a0911528058e87d22ea305695f4047572c5e067
     # BACKCOMPAT: rust 1.60
@@ -70,82 +84,71 @@ def unwrap_unique_or_non_null(unique_or_nonnull):
 
 
 class DefaultSyntheticProvider:
-    def __init__(self, valobj, dict):
-        # type: (SBValue, dict) -> DefaultSyntheticProvider
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque):
         # logger = Logger.Logger()
         # logger >> "Default synthetic provider for " + str(valobj.GetName())
         self.valobj = valobj
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         return self.valobj.GetNumChildren()
 
-    def get_child_index(self, name):
-        # type: (str) -> int
+    def get_child_index(self, name: str) -> int:
         return self.valobj.GetIndexOfChildWithName(name)
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         return self.valobj.GetChildAtIndex(index)
 
     def update(self):
-        # type: () -> None
         pass
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return self.valobj.MightHaveChildren()
 
 
 class EmptySyntheticProvider:
-    def __init__(self, valobj, dict):
-        # type: (SBValue, dict) -> EmptySyntheticProvider
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque):
         # logger = Logger.Logger()
         # logger >> "[EmptySyntheticProvider] for " + str(valobj.GetName())
         self.valobj = valobj
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         return 0
 
-    def get_child_index(self, name):
-        # type: (str) -> int
-        return None
+    def get_child_index(self, name: str) -> int:
+        return -1
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         return None
 
     def update(self):
-        # type: () -> None
         pass
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return False
 
 
-def SizeSummaryProvider(valobj, dict):
-    # type: (SBValue, dict) -> str
-    return 'size=' + str(valobj.GetNumChildren())
+def SizeSummaryProvider(valobj: SBValue, _dict: LLDBOpaque) -> str:
+    return "size=" + str(valobj.GetNumChildren())
 
 
-def vec_to_string(vec):
+def vec_to_string(vec: SBValue) -> str:
     length = vec.GetNumChildren()
     chars = [vec.GetChildAtIndex(i).GetValueAsUnsigned() for i in range(length)]
-    return bytes(chars).decode(errors='replace') if PY3 else "".join(chr(char) for char in chars)
+    return (
+        bytes(chars).decode(errors="replace")
+        if PY3
+        else "".join(chr(char) for char in chars)
+    )
 
 
-def StdStringSummaryProvider(valobj, dict):
-    # type: (SBValue, dict) -> str
+def StdStringSummaryProvider(valobj: SBValue, _dict: LLDBOpaque) -> str:
     # logger = Logger.Logger()
     # logger >> "[StdStringSummaryProvider] for " + str(valobj.GetName())
     vec = valobj.GetChildAtIndex(0)
     return '"%s"' % vec_to_string(vec)
 
 
-def StdOsStringSummaryProvider(valobj, dict):
-    # type: (SBValue, dict) -> str
+def StdOsStringSummaryProvider(valobj: SBValue, _dict: LLDBOpaque) -> str:
     # logger = Logger.Logger()
     # logger >> "[StdOsStringSummaryProvider] for " + str(valobj.GetName())
     buf = valobj.GetChildAtIndex(0).GetChildAtIndex(0)
@@ -154,8 +157,7 @@ def StdOsStringSummaryProvider(valobj, dict):
     return '"%s"' % vec_to_string(vec)
 
 
-def StdStrSummaryProvider(valobj, dict):
-    # type: (SBValue, dict) -> str
+def StdStrSummaryProvider(valobj: SBValue, _dict: LLDBOpaque) -> str:
     # logger = Logger.Logger()
     # logger >> "[StdStrSummaryProvider] for " + str(valobj.GetName())
 
@@ -172,19 +174,17 @@ def StdStrSummaryProvider(valobj, dict):
     error = SBError()
     process = data_ptr.GetProcess()
     data = process.ReadMemory(start, length, error)
-    data = data.decode(encoding='UTF-8') if PY3 else data
+    data = data.decode(encoding="UTF-8") if PY3 else data
     return '"%s"' % data
 
 
-def StdPathBufSummaryProvider(valobj, dict):
-    # type: (SBValue, dict) -> str
+def StdPathBufSummaryProvider(valobj: SBValue, _dict: LLDBOpaque) -> str:
     # logger = Logger.Logger()
     # logger >> "[StdPathBufSummaryProvider] for " + str(valobj.GetName())
-    return StdOsStringSummaryProvider(valobj.GetChildMemberWithName("inner"), dict)
+    return StdOsStringSummaryProvider(valobj.GetChildMemberWithName("inner"), _dict)
 
 
-def StdPathSummaryProvider(valobj, dict):
-    # type: (SBValue, dict) -> str
+def StdPathSummaryProvider(valobj: SBValue, _dict: LLDBOpaque) -> str:
     # logger = Logger.Logger()
     # logger >> "[StdPathSummaryProvider] for " + str(valobj.GetName())
     length = valobj.GetChildMemberWithName("length").GetValueAsUnsigned()
@@ -199,17 +199,16 @@ def StdPathSummaryProvider(valobj, dict):
     data = process.ReadMemory(start, length, error)
     if PY3:
         try:
-            data = data.decode(encoding='UTF-8')
+            data = data.decode(encoding="UTF-8")
         except UnicodeDecodeError:
-            return '%r' % data
+            return "%r" % data
     return '"%s"' % data
 
 
 class StructSyntheticProvider:
     """Pretty-printer for structs and struct enum variants"""
 
-    def __init__(self, valobj, dict, is_variant=False):
-        # type: (SBValue, dict, bool) -> StructSyntheticProvider
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque, is_variant: bool = False):
         # logger = Logger.Logger()
         self.valobj = valobj
         self.is_variant = is_variant
@@ -226,16 +225,13 @@ class StructSyntheticProvider:
         for number, field in enumerate(real_fields):
             self.fields[field.name] = number
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         return self.fields_count
 
-    def get_child_index(self, name):
-        # type: (str) -> int
+    def get_child_index(self, name: str) -> int:
         return self.fields.get(name, -1)
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         if self.is_variant:
             field = self.type.GetFieldAtIndex(index + 1)
         else:
@@ -246,55 +242,63 @@ class StructSyntheticProvider:
         # type: () -> None
         pass
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return True
 
+
 class ClangEncodedEnumProvider:
     """Pretty-printer for 'clang-encoded' enums support implemented in LLDB"""
+
     DISCRIMINANT_MEMBER_NAME = "$discr$"
     VALUE_MEMBER_NAME = "value"
 
-    def __init__(self, valobj, dict):
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque):
         self.valobj = valobj
         self.update()
 
-    def has_children(self):
-       return True
+    def has_children(self) -> bool:
+        return True
 
-    def num_children(self):
+    def num_children(self) -> int:
         if self.is_default:
             return 1
         return 2
 
-    def get_child_index(self, name):
+    def get_child_index(self, name: str) -> int:
         if name == ClangEncodedEnumProvider.VALUE_MEMBER_NAME:
             return 0
         if name == ClangEncodedEnumProvider.DISCRIMINANT_MEMBER_NAME:
             return 1
         return -1
 
-    def get_child_at_index(self, index):
+    def get_child_at_index(self, index: int) -> SBValue:
         if index == 0:
-            return self.variant.GetChildMemberWithName(ClangEncodedEnumProvider.VALUE_MEMBER_NAME)
+            return self.variant.GetChildMemberWithName(
+                ClangEncodedEnumProvider.VALUE_MEMBER_NAME
+            )
         if index == 1:
             return self.variant.GetChildMemberWithName(
-                ClangEncodedEnumProvider.DISCRIMINANT_MEMBER_NAME)
-
+                ClangEncodedEnumProvider.DISCRIMINANT_MEMBER_NAME
+            )
 
     def update(self):
         all_variants = self.valobj.GetChildAtIndex(0)
         index = self._getCurrentVariantIndex(all_variants)
         self.variant = all_variants.GetChildAtIndex(index)
-        self.is_default = self.variant.GetIndexOfChildWithName(
-            ClangEncodedEnumProvider.DISCRIMINANT_MEMBER_NAME) == -1
+        self.is_default = (
+            self.variant.GetIndexOfChildWithName(
+                ClangEncodedEnumProvider.DISCRIMINANT_MEMBER_NAME
+            )
+            == -1
+        )
 
-    def _getCurrentVariantIndex(self, all_variants):
+    def _getCurrentVariantIndex(self, all_variants: SBValue) -> int:
         default_index = 0
         for i in range(all_variants.GetNumChildren()):
             variant = all_variants.GetChildAtIndex(i)
             discr = variant.GetChildMemberWithName(
-                ClangEncodedEnumProvider.DISCRIMINANT_MEMBER_NAME)
+                ClangEncodedEnumProvider.DISCRIMINANT_MEMBER_NAME
+            )
             if discr.IsValid():
                 discr_unsigned_value = discr.GetValueAsUnsigned()
                 if variant.GetName() == f"$variant${discr_unsigned_value}":
@@ -303,11 +307,11 @@ class ClangEncodedEnumProvider:
                 default_index = i
         return default_index
 
+
 class TupleSyntheticProvider:
     """Pretty-printer for tuples and tuple enum variants"""
 
-    def __init__(self, valobj, dict, is_variant=False):
-        # type: (SBValue, dict, bool) -> TupleSyntheticProvider
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque, is_variant: bool = False):
         # logger = Logger.Logger()
         self.valobj = valobj
         self.is_variant = is_variant
@@ -318,32 +322,29 @@ class TupleSyntheticProvider:
         else:
             self.size = self.type.GetNumberOfFields()
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         return self.size
 
-    def get_child_index(self, name):
-        # type: (str) -> int
+    def get_child_index(self, name: str) -> int:
         if name.isdigit():
             return int(name)
         else:
             return -1
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         if self.is_variant:
             field = self.type.GetFieldAtIndex(index + 1)
         else:
             field = self.type.GetFieldAtIndex(index)
         element = self.valobj.GetChildMemberWithName(field.name)
-        return self.valobj.CreateValueFromData(str(index), element.GetData(), element.GetType())
+        return self.valobj.CreateValueFromData(
+            str(index), element.GetData(), element.GetType()
+        )
 
     def update(self):
-        # type: () -> None
         pass
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return True
 
 
@@ -360,81 +361,78 @@ class StdVecSyntheticProvider:
     struct NonNull<T> { pointer: *const T }
     """
 
-    def __init__(self, valobj, dict):
-        # type: (SBValue, dict) -> StdVecSyntheticProvider
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque):
         # logger = Logger.Logger()
         # logger >> "[StdVecSyntheticProvider] for " + str(valobj.GetName())
         self.valobj = valobj
         self.update()
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         return self.length
 
-    def get_child_index(self, name):
-        # type: (str) -> int
-        index = name.lstrip('[').rstrip(']')
+    def get_child_index(self, name: str) -> int:
+        index = name.lstrip("[").rstrip("]")
         if index.isdigit():
             return int(index)
         else:
             return -1
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         start = self.data_ptr.GetValueAsUnsigned()
         address = start + index * self.element_type_size
-        element = self.data_ptr.CreateValueFromAddress("[%s]" % index, address, self.element_type)
+        element = self.data_ptr.CreateValueFromAddress(
+            "[%s]" % index, address, self.element_type
+        )
         return element
 
     def update(self):
-        # type: () -> None
         self.length = self.valobj.GetChildMemberWithName("len").GetValueAsUnsigned()
-        self.buf = self.valobj.GetChildMemberWithName("buf").GetChildMemberWithName("inner")
+        self.buf = self.valobj.GetChildMemberWithName("buf").GetChildMemberWithName(
+            "inner"
+        )
 
-        self.data_ptr = unwrap_unique_or_non_null(self.buf.GetChildMemberWithName("ptr"))
+        self.data_ptr = unwrap_unique_or_non_null(
+            self.buf.GetChildMemberWithName("ptr")
+        )
 
         self.element_type = self.valobj.GetType().GetTemplateArgumentType(0)
         self.element_type_size = self.element_type.GetByteSize()
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return True
 
 
 class StdSliceSyntheticProvider:
-    def __init__(self, valobj, dict):
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque):
         self.valobj = valobj
         self.update()
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         return self.length
 
-    def get_child_index(self, name):
-        # type: (str) -> int
-        index = name.lstrip('[').rstrip(']')
+    def get_child_index(self, name: str) -> int:
+        index = name.lstrip("[").rstrip("]")
         if index.isdigit():
             return int(index)
         else:
             return -1
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         start = self.data_ptr.GetValueAsUnsigned()
         address = start + index * self.element_type_size
-        element = self.data_ptr.CreateValueFromAddress("[%s]" % index, address, self.element_type)
+        element = self.data_ptr.CreateValueFromAddress(
+            "[%s]" % index, address, self.element_type
+        )
         return element
 
     def update(self):
-        # type: () -> None
         self.length = self.valobj.GetChildMemberWithName("length").GetValueAsUnsigned()
         self.data_ptr = self.valobj.GetChildMemberWithName("data_ptr")
 
         self.element_type = self.data_ptr.GetType().GetPointeeType()
         self.element_type_size = self.element_type.GetByteSize()
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return True
 
 
@@ -444,49 +442,49 @@ class StdVecDequeSyntheticProvider:
     struct VecDeque<T> { head: usize, len: usize, buf: RawVec<T> }
     """
 
-    def __init__(self, valobj, dict):
-        # type: (SBValue, dict) -> StdVecDequeSyntheticProvider
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque):
         # logger = Logger.Logger()
         # logger >> "[StdVecDequeSyntheticProvider] for " + str(valobj.GetName())
         self.valobj = valobj
         self.update()
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         return self.size
 
-    def get_child_index(self, name):
-        # type: (str) -> int
-        index = name.lstrip('[').rstrip(']')
+    def get_child_index(self, name: str) -> int:
+        index = name.lstrip("[").rstrip("]")
         if index.isdigit() and int(index) < self.size:
             return int(index)
         else:
             return -1
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         start = self.data_ptr.GetValueAsUnsigned()
         address = start + ((index + self.head) % self.cap) * self.element_type_size
-        element = self.data_ptr.CreateValueFromAddress("[%s]" % index, address, self.element_type)
+        element = self.data_ptr.CreateValueFromAddress(
+            "[%s]" % index, address, self.element_type
+        )
         return element
 
     def update(self):
-        # type: () -> None
         self.head = self.valobj.GetChildMemberWithName("head").GetValueAsUnsigned()
         self.size = self.valobj.GetChildMemberWithName("len").GetValueAsUnsigned()
-        self.buf = self.valobj.GetChildMemberWithName("buf").GetChildMemberWithName("inner")
+        self.buf = self.valobj.GetChildMemberWithName("buf").GetChildMemberWithName(
+            "inner"
+        )
         cap = self.buf.GetChildMemberWithName("cap")
         if cap.GetType().num_fields == 1:
             cap = cap.GetChildAtIndex(0)
         self.cap = cap.GetValueAsUnsigned()
 
-        self.data_ptr = unwrap_unique_or_non_null(self.buf.GetChildMemberWithName("ptr"))
+        self.data_ptr = unwrap_unique_or_non_null(
+            self.buf.GetChildMemberWithName("ptr")
+        )
 
         self.element_type = self.valobj.GetType().GetTemplateArgumentType(0)
         self.element_type_size = self.element_type.GetByteSize()
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return True
 
 
@@ -498,26 +496,22 @@ class StdOldHashMapSyntheticProvider:
     struct RawTable<K, V> { capacity_mask: usize, size: usize, hashes: TaggedHashUintPtr, ... }
     """
 
-    def __init__(self, valobj, dict, show_values=True):
-        # type: (SBValue, dict, bool) -> StdOldHashMapSyntheticProvider
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque, show_values: bool = True):
         self.valobj = valobj
         self.show_values = show_values
         self.update()
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         return self.size
 
-    def get_child_index(self, name):
-        # type: (str) -> int
-        index = name.lstrip('[').rstrip(']')
+    def get_child_index(self, name: str) -> int:
+        index = name.lstrip("[").rstrip("]")
         if index.isdigit():
             return int(index)
         else:
             return -1
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         # logger = Logger.Logger()
         start = self.data_ptr.GetValueAsUnsigned() & ~1
 
@@ -525,8 +519,14 @@ class StdOldHashMapSyntheticProvider:
         hashes = self.hash_uint_size * self.capacity
         align = self.pair_type_size
         # See `libcore/alloc.rs:padding_needed_for`
-        len_rounded_up = (((((hashes + align) % self.modulo - 1) % self.modulo) & ~(
-                (align - 1) % self.modulo)) % self.modulo - hashes) % self.modulo
+        len_rounded_up = (
+            (
+                (((hashes + align) % self.modulo - 1) % self.modulo)
+                & ~((align - 1) % self.modulo)
+            )
+            % self.modulo
+            - hashes
+        ) % self.modulo
         # len_rounded_up = ((hashes + align - 1) & ~(align - 1)) - hashes
 
         pairs_offset = hashes + len_rounded_up
@@ -535,15 +535,18 @@ class StdOldHashMapSyntheticProvider:
         table_index = self.valid_indices[index]
         idx = table_index & self.capacity_mask
         address = pairs_start + idx * self.pair_type_size
-        element = self.data_ptr.CreateValueFromAddress("[%s]" % index, address, self.pair_type)
+        element = self.data_ptr.CreateValueFromAddress(
+            "[%s]" % index, address, self.pair_type
+        )
         if self.show_values:
             return element
         else:
             key = element.GetChildAtIndex(0)
-            return self.valobj.CreateValueFromData("[%s]" % index, key.GetData(), key.GetType())
+            return self.valobj.CreateValueFromData(
+                "[%s]" % index, key.GetData(), key.GetType()
+            )
 
     def update(self):
-        # type: () -> None
         # logger = Logger.Logger()
 
         self.table = self.valobj.GetChildMemberWithName("table")  # type: SBValue
@@ -551,10 +554,12 @@ class StdOldHashMapSyntheticProvider:
         self.hashes = self.table.GetChildMemberWithName("hashes")
         self.hash_uint_type = self.hashes.GetType()
         self.hash_uint_size = self.hashes.GetType().GetByteSize()
-        self.modulo = 2 ** self.hash_uint_size
+        self.modulo = 2**self.hash_uint_size
         self.data_ptr = self.hashes.GetChildAtIndex(0).GetChildAtIndex(0)
 
-        self.capacity_mask = self.table.GetChildMemberWithName("capacity_mask").GetValueAsUnsigned()
+        self.capacity_mask = self.table.GetChildMemberWithName(
+            "capacity_mask"
+        ).GetValueAsUnsigned()
         self.capacity = (self.capacity_mask + 1) % self.modulo
 
         marker = self.table.GetChildMemberWithName("marker").GetType()  # type: SBType
@@ -564,60 +569,61 @@ class StdOldHashMapSyntheticProvider:
         self.valid_indices = []
         for idx in range(self.capacity):
             address = self.data_ptr.GetValueAsUnsigned() + idx * self.hash_uint_size
-            hash_uint = self.data_ptr.CreateValueFromAddress("[%s]" % idx, address,
-                                                             self.hash_uint_type)
+            hash_uint = self.data_ptr.CreateValueFromAddress(
+                "[%s]" % idx, address, self.hash_uint_type
+            )
             hash_ptr = hash_uint.GetChildAtIndex(0).GetChildAtIndex(0)
             if hash_ptr.GetValueAsUnsigned() != 0:
                 self.valid_indices.append(idx)
 
         # logger >> "Valid indices: {}".format(str(self.valid_indices))
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return True
 
 
 class StdHashMapSyntheticProvider:
     """Pretty-printer for hashbrown's HashMap"""
 
-    def __init__(self, valobj, dict, show_values=True):
-        # type: (SBValue, dict, bool) -> StdHashMapSyntheticProvider
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque, show_values: bool = True):
         self.valobj = valobj
         self.show_values = show_values
         self.update()
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         return self.size
 
-    def get_child_index(self, name):
-        # type: (str) -> int
-        index = name.lstrip('[').rstrip(']')
+    def get_child_index(self, name: str) -> int:
+        index = name.lstrip("[").rstrip("]")
         if index.isdigit():
             return int(index)
         else:
             return -1
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         pairs_start = self.data_ptr.GetValueAsUnsigned()
         idx = self.valid_indices[index]
         if self.new_layout:
             idx = -(idx + 1)
         address = pairs_start + idx * self.pair_type_size
-        element = self.data_ptr.CreateValueFromAddress("[%s]" % index, address, self.pair_type)
+        element = self.data_ptr.CreateValueFromAddress(
+            "[%s]" % index, address, self.pair_type
+        )
         if self.show_values:
             return element
         else:
             key = element.GetChildAtIndex(0)
-            return self.valobj.CreateValueFromData("[%s]" % index, key.GetData(), key.GetType())
+            return self.valobj.CreateValueFromData(
+                "[%s]" % index, key.GetData(), key.GetType()
+            )
 
     def update(self):
-        # type: () -> None
         table = self.table()
         inner_table = table.GetChildMemberWithName("table")
 
-        capacity = inner_table.GetChildMemberWithName("bucket_mask").GetValueAsUnsigned() + 1
+        capacity = (
+            inner_table.GetChildMemberWithName("bucket_mask").GetValueAsUnsigned() + 1
+        )
         ctrl = inner_table.GetChildMemberWithName("ctrl").GetChildAtIndex(0)
 
         self.size = inner_table.GetChildMemberWithName("items").GetValueAsUnsigned()
@@ -630,22 +636,26 @@ class StdHashMapSyntheticProvider:
         if self.new_layout:
             self.data_ptr = ctrl.Cast(self.pair_type.GetPointerType())
         else:
-            self.data_ptr = inner_table.GetChildMemberWithName("data").GetChildAtIndex(0)
+            self.data_ptr = inner_table.GetChildMemberWithName("data").GetChildAtIndex(
+                0
+            )
 
         u8_type = self.valobj.GetTarget().GetBasicType(eBasicTypeUnsignedChar)
-        u8_type_size = self.valobj.GetTarget().GetBasicType(eBasicTypeUnsignedChar).GetByteSize()
+        u8_type_size = (
+            self.valobj.GetTarget().GetBasicType(eBasicTypeUnsignedChar).GetByteSize()
+        )
 
         self.valid_indices = []
         for idx in range(capacity):
             address = ctrl.GetValueAsUnsigned() + idx * u8_type_size
-            value = ctrl.CreateValueFromAddress("ctrl[%s]" % idx, address,
-                                                u8_type).GetValueAsUnsigned()
+            value = ctrl.CreateValueFromAddress(
+                "ctrl[%s]" % idx, address, u8_type
+            ).GetValueAsUnsigned()
             is_present = value & 128 == 0
             if is_present:
                 self.valid_indices.append(idx)
 
-    def table(self):
-        # type: () -> SBValue
+    def table(self) -> SBValue:
         if self.show_values:
             hashbrown_hashmap = self.valobj.GetChildMemberWithName("base")
         else:
@@ -655,13 +665,11 @@ class StdHashMapSyntheticProvider:
             hashbrown_hashmap = self.valobj.GetChildAtIndex(0).GetChildAtIndex(0)
         return hashbrown_hashmap.GetChildMemberWithName("table")
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return True
 
 
-def StdRcSummaryProvider(valobj, dict):
-    # type: (SBValue, dict) -> str
+def StdRcSummaryProvider(valobj: SBValue, _dict: LLDBOpaque) -> str:
     strong = valobj.GetChildMemberWithName("strong").GetValueAsUnsigned()
     weak = valobj.GetChildMemberWithName("weak").GetValueAsUnsigned()
     return "strong={}, weak={}".format(strong, weak)
@@ -683,30 +691,33 @@ class StdRcSyntheticProvider:
     struct AtomicUsize { v: UnsafeCell<usize> }
     """
 
-    def __init__(self, valobj, dict, is_atomic=False):
-        # type: (SBValue, dict, bool) -> StdRcSyntheticProvider
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque, is_atomic: bool = False):
         self.valobj = valobj
 
         self.ptr = unwrap_unique_or_non_null(self.valobj.GetChildMemberWithName("ptr"))
 
         self.value = self.ptr.GetChildMemberWithName("data" if is_atomic else "value")
 
-        self.strong = self.ptr.GetChildMemberWithName("strong").GetChildAtIndex(
-            0).GetChildMemberWithName("value")
-        self.weak = self.ptr.GetChildMemberWithName("weak").GetChildAtIndex(
-            0).GetChildMemberWithName("value")
+        self.strong = (
+            self.ptr.GetChildMemberWithName("strong")
+            .GetChildAtIndex(0)
+            .GetChildMemberWithName("value")
+        )
+        self.weak = (
+            self.ptr.GetChildMemberWithName("weak")
+            .GetChildAtIndex(0)
+            .GetChildMemberWithName("value")
+        )
 
         self.value_builder = ValueBuilder(valobj)
 
         self.update()
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         # Actually there are 3 children, but only the `value` should be shown as a child
         return 1
 
-    def get_child_index(self, name):
-        # type: (str) -> int
+    def get_child_index(self, name: str) -> int:
         if name == "value":
             return 0
         if name == "strong":
@@ -715,8 +726,7 @@ class StdRcSyntheticProvider:
             return 2
         return -1
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         if index == 0:
             return self.value
         if index == 1:
@@ -727,89 +737,84 @@ class StdRcSyntheticProvider:
         return None
 
     def update(self):
-        # type: () -> None
         self.strong_count = self.strong.GetValueAsUnsigned()
         self.weak_count = self.weak.GetValueAsUnsigned() - 1
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return True
 
 
 class StdCellSyntheticProvider:
     """Pretty-printer for std::cell::Cell"""
 
-    def __init__(self, valobj, dict):
-        # type: (SBValue, dict) -> StdCellSyntheticProvider
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque):
         self.valobj = valobj
         self.value = valobj.GetChildMemberWithName("value").GetChildAtIndex(0)
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         return 1
 
-    def get_child_index(self, name):
-        # type: (str) -> int
+    def get_child_index(self, name: str) -> int:
         if name == "value":
             return 0
         return -1
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         if index == 0:
             return self.value
         return None
 
     def update(self):
-        # type: () -> None
         pass
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return True
 
 
-def StdRefSummaryProvider(valobj, dict):
-    # type: (SBValue, dict) -> str
+def StdRefSummaryProvider(valobj: SBValue, _dict: LLDBOpaque) -> str:
     borrow = valobj.GetChildMemberWithName("borrow").GetValueAsSigned()
-    return "borrow={}".format(borrow) if borrow >= 0 else "borrow_mut={}".format(-borrow)
+    return (
+        "borrow={}".format(borrow) if borrow >= 0 else "borrow_mut={}".format(-borrow)
+    )
 
 
 class StdRefSyntheticProvider:
     """Pretty-printer for std::cell::Ref, std::cell::RefMut, and std::cell::RefCell"""
 
-    def __init__(self, valobj, dict, is_cell=False):
-        # type: (SBValue, dict, bool) -> StdRefSyntheticProvider
+    def __init__(self, valobj: SBValue, _dict: LLDBOpaque, is_cell: bool = False):
         self.valobj = valobj
 
         borrow = valobj.GetChildMemberWithName("borrow")
         value = valobj.GetChildMemberWithName("value")
         if is_cell:
-            self.borrow = borrow.GetChildMemberWithName("value").GetChildMemberWithName("value")
+            self.borrow = borrow.GetChildMemberWithName("value").GetChildMemberWithName(
+                "value"
+            )
             self.value = value.GetChildMemberWithName("value")
         else:
-            self.borrow = borrow.GetChildMemberWithName("borrow").GetChildMemberWithName(
-                "value").GetChildMemberWithName("value")
+            self.borrow = (
+                borrow.GetChildMemberWithName("borrow")
+                .GetChildMemberWithName("value")
+                .GetChildMemberWithName("value")
+            )
             self.value = value.Dereference()
 
         self.value_builder = ValueBuilder(valobj)
 
         self.update()
 
-    def num_children(self):
-        # type: () -> int
+    def num_children(self) -> int:
         # Actually there are 2 children, but only the `value` should be shown as a child
         return 1
 
-    def get_child_index(self, name):
+    def get_child_index(self, name: str) -> int:
         if name == "value":
             return 0
         if name == "borrow":
             return 1
         return -1
 
-    def get_child_at_index(self, index):
-        # type: (int) -> SBValue
+    def get_child_at_index(self, index: int) -> SBValue:
         if index == 0:
             return self.value
         if index == 1:
@@ -817,22 +822,19 @@ class StdRefSyntheticProvider:
         return None
 
     def update(self):
-        # type: () -> None
         self.borrow_count = self.borrow.GetValueAsSigned()
 
-    def has_children(self):
-        # type: () -> bool
+    def has_children(self) -> bool:
         return True
 
 
-def StdNonZeroNumberSummaryProvider(valobj, _dict):
-    # type: (SBValue, dict) -> str
+def StdNonZeroNumberSummaryProvider(valobj: SBValue, _dict: LLDBOpaque) -> str:
     inner = valobj.GetChildAtIndex(0)
     inner_inner = inner.GetChildAtIndex(0)
 
     # FIXME: Avoid printing as character literal,
     #        see https://github.com/llvm/llvm-project/issues/65076.
-    if inner_inner.GetTypeName() in ['char', 'unsigned char']:
-      return str(inner_inner.GetValueAsSigned())
+    if inner_inner.GetTypeName() in ["char", "unsigned char"]:
+        return str(inner_inner.GetValueAsSigned())
     else:
-      return inner_inner.GetValue()
+        return inner_inner.GetValue()
